@@ -28,6 +28,13 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_connectivity.hxx"
+
+#ifdef SYSTEM_ODBC_HEADERS
+#include <sqltypes.h>
+#else
+#include <odbc/sqltypes.h>
+#endif
+
 #include <unotools/tempfile.hxx>
 #include <sal/macros.h>
 #include "adabas/BDriver.hxx"
@@ -50,9 +57,7 @@
 #include <memory>
 #include <sys/stat.h>
 
-#if defined(MAC)
-const char sNewLine = '\015';
-#elif defined(UNX)
+#if defined(UNX)
 const char sNewLine = '\012';
 #else
 const char sNewLine[] = "\015\012"; // \015\012 and not \n
@@ -509,23 +514,23 @@ void SAL_CALL ODriver::dropCatalog( const ::rtl::OUString& /*catalogName*/, cons
     ::dbtools::throwFeatureNotImplementedException( "!XDropCatalog::dropCatalog", *this );
 }
 //-----------------------------------------------------------------------------
-// ODBC Environment (gemeinsam fuer alle Connections):
+// ODBC Environment (common for all Connections):
 SQLHANDLE ODriver::EnvironmentHandle(::rtl::OUString &_rPath)
 {
-    // Ist (fuer diese Instanz) bereits ein Environment erzeugt worden?
+    // Has an Environment already been created (for this Instance)?
     if (!m_pDriverHandle)
     {
         SQLHANDLE h = SQL_NULL_HANDLE;
-        // Environment allozieren
+        // allocate Environment
 
-        // ODBC-DLL jetzt laden:
+        // load ODBC-DLL now:
         if (! LoadLibrary_ADABAS(_rPath))
             return SQL_NULL_HANDLE;
 
         if (N3SQLAllocHandle(SQL_HANDLE_ENV,SQL_NULL_HANDLE,&h) != SQL_SUCCESS)
             return SQL_NULL_HANDLE;
 
-        // In globaler Struktur merken ...
+        // Save in global Structure...
         m_pDriverHandle = h;
         SQLRETURN nError = N3SQLSetEnvAttr(h, SQL_ATTR_ODBC_VERSION,(SQLPOINTER) SQL_OV_ODBC3, SQL_IS_INTEGER);
         OSL_UNUSED( nError );
@@ -807,7 +812,7 @@ oslGenericFunction ODriver::getOdbcFunction(sal_Int32 _nIndex) const
             pFunction = (oslGenericFunction)pODBC3SQLNativeSql;
             break;
         default:
-            OSL_ENSURE(0,"Function unknown!");
+            OSL_FAIL("Function unknown!");
     }
     return pFunction;
 }
@@ -857,7 +862,7 @@ void ODriver::createNeededDirs(const ::rtl::OUString& sDBName)
         if(UCBContentHelper::Exists(sTemp))
             UCBContentHelper::Kill(sTemp);
 
-#if !(defined(WIN) || defined(WNT))
+#if !(defined(WNT))
         sTemp = sDBConfig;
         sTemp += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("diag"));
         if(!UCBContentHelper::IsFolder(sTemp))
@@ -879,7 +884,7 @@ void ODriver::createNeededDirs(const ::rtl::OUString& sDBName)
 void ODriver::clearDatabase(const ::rtl::OUString& sDBName)
 { // stop the database
     ::rtl::OUString sCommand;
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
     ::rtl::OUString sStop = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("stop"));
     const sal_uInt32 nArgsCount = 2;
     rtl_uString *pArgs[nArgsCount] = { sDBName.pData, sStop.pData };
@@ -928,7 +933,7 @@ void ODriver::createDb( const TDatabaseStruct& _aInfo)
     PutParam(_aInfo.sDBName,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("KERNELTRACESIZE")),::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("100")));
     PutParam(_aInfo.sDBName,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LOG_QUEUE_PAGES")),::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("10")));
 
-#if !(defined(WIN) || defined(WNT))
+#if !defined(WNT)
     PutParam(_aInfo.sDBName,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("OPMSG1")),::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/dev/null")));
 #endif
 
@@ -996,7 +1001,7 @@ int ODriver::X_PARAM(const ::rtl::OUString& _DBNAME,
         ::std::auto_ptr<SvStream> pFileStream( UcbStreamHelper::CreateStream(sCommandFile,STREAM_STD_READWRITE));
         pFileStream->Seek(STREAM_SEEK_TO_END);
         (*pFileStream)	<< "x_param"
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                         << ".exe"
 #endif
                         << " -d "
@@ -1007,7 +1012,7 @@ int ODriver::X_PARAM(const ::rtl::OUString& _DBNAME,
                         << ::rtl::OString(_PWD,_PWD.getLength(),gsl_getSystemTextEncoding())
                         << " "
                         << ::rtl::OString(_CMD,_CMD.getLength(),gsl_getSystemTextEncoding())
-#if (defined(WIN) || defined(WNT))
+#if defined(WNT)
 #if (OSL_DEBUG_LEVEL > 1) || defined(DBG_UTIL)
                         << " >> %DBWORK%\\create.log 2>&1"
 #endif
@@ -1063,7 +1068,7 @@ void ODriver::PutParam(const ::rtl::OUString& sDBName,
     rtl_uString* pArgs[nArgsCount] = { sDBName.pData, rWhat.pData, rHow.pData  };
 
     ::rtl::OUString sCommand = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("putparam"));
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
     sCommand += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".exe"));
 #endif
 
@@ -1130,7 +1135,7 @@ OSL_TRACE("CreateFile %d",_nSize);
 int ODriver::X_START(const ::rtl::OUString& sDBName)
 {
     ::rtl::OUString sCommand;
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
 
     ::rtl::OUString sArg1 = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-d"));
     ::rtl::OUString sArg3 = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-NoDBService"));
@@ -1164,6 +1169,7 @@ int ODriver::X_START(const ::rtl::OUString& sDBName)
     OSL_ASSERT(eError == osl_Process_E_None);
 
     oslProcessInfo aInfo;
+    aInfo.Size = sizeof(oslProcessInfo);
 
     if(osl_getProcessInfo(aApp, osl_Process_EXITCODE, &aInfo) == osl_Process_E_None && aInfo.Code)
         return aInfo.Code;
@@ -1174,7 +1180,7 @@ int ODriver::X_START(const ::rtl::OUString& sDBName)
 int ODriver::X_STOP(const ::rtl::OUString& sDBName)
 {
     ::rtl::OUString sCommand;
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
 
     ::rtl::OUString sArg1 = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-d"));
     ::rtl::OUString sArg2 = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-NoDBService"));
@@ -1199,6 +1205,7 @@ int ODriver::X_STOP(const ::rtl::OUString& sDBName)
         return 1;
 
     oslProcessInfo aInfo;
+    aInfo.Size = sizeof(oslProcessInfo);
 
     if(osl_getProcessInfo(aApp, osl_Process_EXITCODE, &aInfo) == osl_Process_E_None && aInfo.Code)
         return aInfo.Code;
@@ -1225,7 +1232,7 @@ void ODriver::XUTIL(const ::rtl::OUString& _rParam,
         ::std::auto_ptr<SvStream> pFileStream( UcbStreamHelper::CreateStream(sCommandFile,STREAM_STD_READWRITE));
         pFileStream->Seek(STREAM_SEEK_TO_END);
         (*pFileStream)	<<
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                             "xutil.exe"
 #else
                             "utility"
@@ -1283,7 +1290,7 @@ void ODriver::LoadBatch(const ::rtl::OUString& sDBName,
         ::std::auto_ptr<SvStream> pFileStream( UcbStreamHelper::CreateStream(sCommandFile,STREAM_STD_READWRITE));
         pFileStream->Seek(STREAM_SEEK_TO_END);
         (*pFileStream)	<< "xload"
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                         << ".exe"
 #endif
                         << " -d "
@@ -1357,7 +1364,7 @@ void ODriver::fillEnvironmentVariables()
 ::rtl::OUString ODriver::generateInitFile() const
 {
     String sExt;
-#if !(defined(WIN) || defined(WNT))
+#if !defined(WNT)
     sExt = String::CreateFromAscii(".sh");
 #else
     sExt = String::CreateFromAscii(".bat");
@@ -1365,13 +1372,13 @@ void ODriver::fillEnvironmentVariables()
 
     String sWorkUrl(m_sDbWorkURL);
     ::utl::TempFile aCmdFile(String::CreateFromAscii("Init"),&sExt,&sWorkUrl);
-#if !(defined(WIN) || defined(WNT))
+#if !defined(WNT)
     String sPhysicalPath;
     LocalFileHelper::ConvertURLToPhysicalName(aCmdFile.GetURL(),sPhysicalPath);
     chmod(ByteString(sPhysicalPath,gsl_getSystemTextEncoding()).GetBuffer(),S_IRUSR|S_IWUSR|S_IXUSR);
 #endif
 
-#if !(defined(WIN) || defined(WNT))
+#if !defined(WNT)
     SvStream* pFileStream = aCmdFile.GetStream(STREAM_WRITE);
     (*pFileStream)	<< "#!/bin/sh"
                     << sNewLine
@@ -1481,7 +1488,7 @@ void ODriver::X_CONS(const ::rtl::OUString& sDBName,const ::rtl::OString& _ACTIO
         pFileStream->Seek(STREAM_SEEK_TO_END);
 
         (*pFileStream)	<< "x_cons"
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                         << ".exe"
 #endif
                         << " "
@@ -1568,7 +1575,7 @@ sal_Bool ODriver::isVersion(const ::rtl::OUString& sDBName, const char* _pVersio
         pFileStream->Seek(STREAM_SEEK_TO_END);
 
         (*pFileStream)	<< "getparam"
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                         << ".exe"
 #endif
                         << " "
@@ -1622,7 +1629,7 @@ void ODriver::checkAndInsertNewDevSpace(const ::rtl::OUString& sDBName,
         pFileStream->Seek(STREAM_SEEK_TO_END);
 
         (*pFileStream)	<< "getparam"
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
                         << ".exe"
 #endif
                         << " "
@@ -1708,7 +1715,7 @@ sal_Bool ODriver::isKernelVersion(const char* _pVersion)
 // -----------------------------------------------------------------------------
 void ODriver::installSystemTables(	const TDatabaseStruct& _aInfo)
 {
-#if defined(WIN) || defined(WNT)
+#if defined(WNT)
     //	xutil -d %_DBNAME% -u %_CONTROL_USER%,%_CONTROL_PWD% -b %m_sDbRoot%\env\TERMCHAR.ind
     ::rtl::OUString aBatch =  ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("-b "));
     ::rtl::OUString sTemp2 = m_sDbRootURL	+ m_sDelimit
