@@ -448,7 +448,7 @@ MacabHeader *MacabRecords::createHeaderForRecordType(const CFArrayRef _records,
         else
         {
             // Couldn't find a required property...
-            OSL_ENSURE(false, ::rtl::OString("MacabRecords::createHeaderForRecordType: could not find required property: ") +
+            OSL_FAIL(::rtl::OString("MacabRecords::createHeaderForRecordType: could not find required property: ") +
                         ::rtl::OUStringToOString(CFStringToOUString(requiredProperties[i]), RTL_TEXTENCODING_ASCII_US));
         }
     }
@@ -568,7 +568,7 @@ MacabHeader *MacabRecords::createHeaderForProperty(const ABPropertyType _propert
                 multiLabelString = CFStringToOUString(localizedMultiLabel);
                 CFRelease(multiLabel);
                 CFRelease(localizedMultiLabel);
-                headerNameString = multiPropertyString + ::rtl::OUString::createFromAscii(": ") + fixLabel(multiLabelString);
+                headerNameString = multiPropertyString + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(": ")) + fixLabel(multiLabelString);
                 headerNames[i] = new macabfield;
                 headerNames[i]->value = OUStringToCFString(headerNameString);
                 headerNames[i]->type = multiType;
@@ -619,7 +619,7 @@ MacabHeader *MacabRecords::createHeaderForProperty(const ABPropertyType _propert
                     if(multiValue && multiLabel)
                     {
                         localizedMultiLabel = ABCopyLocalizedPropertyOrLabel(multiLabel);
-                        multiLabelString = multiPropertyString + ::rtl::OUString::createFromAscii(": ") + fixLabel(CFStringToOUString(localizedMultiLabel));
+                        multiLabelString = multiPropertyString + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(": ")) + fixLabel(CFStringToOUString(localizedMultiLabel));
                         CFRelease(multiLabel);
                         CFRelease(localizedMultiLabel);
                         multiLabel = OUStringToCFString(multiLabelString);
@@ -707,7 +707,7 @@ MacabHeader *MacabRecords::createHeaderForProperty(const ABPropertyType _propert
                 dictType = (ABPropertyType) getABTypeFromCFType( CFGetTypeID(dictValues[i]) );
                 localizedDictKey = ABCopyLocalizedPropertyOrLabel(dictKeys[i]);
                 dictKeyString = CFStringToOUString(localizedDictKey);
-                dictLabelString = propertyNameString + ::rtl::OUString::createFromAscii(": ") + fixLabel(dictKeyString);
+                dictLabelString = propertyNameString + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(": ")) + fixLabel(dictKeyString);
                 dictLabel = OUStringToCFString(dictLabelString);
                 dictHeaders[i] = createHeaderForProperty(dictType, dictValues[i], dictLabel);
                 if (!dictHeaders[i])
@@ -847,7 +847,7 @@ void MacabRecords::manageDuplicateHeaders(macabfield **_headerNames, const sal_I
             // There is probably a better way to do this...
             ::rtl::OUString newName = CFStringToOUString((CFStringRef) _headerNames[i]->value);
             CFRelease(_headerNames[i]->value);
-            newName += ::rtl::OUString::createFromAscii(" (") + ::rtl::OUString::valueOf(count) + ::rtl::OUString::createFromAscii(")");
+            newName += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(" (")) + ::rtl::OUString::valueOf(count) + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(")"));
             _headerNames[i]->value = OUStringToCFString(newName);
         }
     }
@@ -939,7 +939,7 @@ void MacabRecords::insertPropertyIntoMacabRecord(const ABPropertyType _propertyT
              * scalar type, an error, or an unknown type are found.
              * Because of that, the following checks only occur for this type.
              * We store whether we have successfully placed this property
-             * into the MacabRecord (or whether an unrecoverable error occured).
+             * into the MacabRecord (or whether an unrecoverable error occurred).
              * Then, we try over and over again to place the property into the
              * record. There are three possible results:
              * 1) Success!
@@ -968,7 +968,7 @@ void MacabRecords::insertPropertyIntoMacabRecord(const ABPropertyType _propertyT
                     {
                         bPlaced = sal_False;
                         i++;
-                        columnName = ::rtl::OUString(_propertyName) + ::rtl::OUString::createFromAscii(" (") + ::rtl::OUString::valueOf(i) + ::rtl::OUString::createFromAscii(")");
+                        columnName = ::rtl::OUString(_propertyName) + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(" (")) + ::rtl::OUString::valueOf(i) + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(")"));
                     }
 
                     // success!
@@ -1040,7 +1040,7 @@ void MacabRecords::insertPropertyIntoMacabRecord(const ABPropertyType _propertyT
                     localizedDictKey = ABCopyLocalizedPropertyOrLabel(dictKeys[i]);
                     dictKeyString = CFStringToOUString(localizedDictKey);
                     CFRelease(localizedDictKey);
-                    newPropertyName = _propertyName + ::rtl::OUString::createFromAscii(": ") + fixLabel(dictKeyString);
+                    newPropertyName = _propertyName + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(": ")) + fixLabel(dictKeyString);
                     insertPropertyIntoMacabRecord(_abrecord, _header, newPropertyName, dictValues[i]);
                 }
 
@@ -1083,7 +1083,7 @@ void MacabRecords::insertPropertyIntoMacabRecord(const ABPropertyType _propertyT
 
                     localizedMultiLabel = ABCopyLocalizedPropertyOrLabel(multiLabel);
                     multiLabelString = CFStringToOUString(localizedMultiLabel);
-                    newPropertyName = _propertyName + ::rtl::OUString::createFromAscii(": ") + fixLabel(multiLabelString);
+                    newPropertyName = _propertyName + ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(": ")) + fixLabel(multiLabelString);
                     insertPropertyIntoMacabRecord(multiType, _abrecord, _header, newPropertyName, multiValue);
 
                     /* free our variables */
@@ -1154,10 +1154,11 @@ MacabRecords::iterator::~iterator ()
 }
 
 // -------------------------------------------------------------------------
-void MacabRecords::iterator::operator= (MacabRecords *_records)
+MacabRecords::iterator& MacabRecords::iterator::operator= (MacabRecords *_records)
 {
     id = 0;
     records = _records;
+    return *this;
 }
 
 // -------------------------------------------------------------------------
