@@ -43,7 +43,7 @@ using namespace ::com::sun::star;
 using namespace ::rtl;
 using namespace ::cppu;
 
-const USHORT NON_USER_DEFINED_GLUE_POINTS = 4;
+const sal_uInt16 NON_USER_DEFINED_GLUE_POINTS = 4;
 
 class SvxUnoGluePointAccess : public WeakImplHelper2< container::XIndexContainer, container::XIdentifierContainer >
 {
@@ -236,7 +236,7 @@ sal_Int32 SAL_CALL SvxUnoGluePointAccess::insert( const uno::Any& aElement ) thr
             {
                 SdrGluePoint aSdrGlue;
                 convert( aUnoGlue, aSdrGlue );
-                USHORT nId = pList->Insert( aSdrGlue );
+                sal_uInt16 nId = pList->Insert( aSdrGlue );
 
                 // only repaint, no objectchange
                 mpObject->ActionChanged();
@@ -256,11 +256,11 @@ void SAL_CALL SvxUnoGluePointAccess::removeByIdentifier( sal_Int32 Identifier )
 {
     if( mpObject.is() && ( Identifier >= NON_USER_DEFINED_GLUE_POINTS ))
     {
-        const USHORT nId = (USHORT)(Identifier - NON_USER_DEFINED_GLUE_POINTS) + 1;
+        const sal_uInt16 nId = (sal_uInt16)(Identifier - NON_USER_DEFINED_GLUE_POINTS) + 1;
 
         SdrGluePointList* pList = const_cast<SdrGluePointList*>(mpObject->GetGluePointList());
-        const USHORT nCount = pList ? pList->GetCount() : 0;
-        USHORT i;
+        const sal_uInt16 nCount = pList ? pList->GetCount() : 0;
+        sal_uInt16 i;
 
         for( i = 0; i < nCount; i++ )
         {
@@ -289,11 +289,11 @@ void SAL_CALL SvxUnoGluePointAccess::replaceByIdentifer( sal_Int32 Identifier, c
         if( (Identifier < NON_USER_DEFINED_GLUE_POINTS) || !(aElement >>= aGluePoint))
             throw lang::IllegalArgumentException();
 
-        const USHORT nId = (USHORT)( Identifier - NON_USER_DEFINED_GLUE_POINTS ) + 1;
+        const sal_uInt16 nId = (sal_uInt16)( Identifier - NON_USER_DEFINED_GLUE_POINTS ) + 1;
 
         SdrGluePointList* pList = const_cast< SdrGluePointList* >( mpObject->GetGluePointList() );
-        const USHORT nCount = pList ? pList->GetCount() : 0;
-        USHORT i;
+        const sal_uInt16 nCount = pList ? pList->GetCount() : 0;
+        sal_uInt16 i;
         for( i = 0; i < nCount; i++ )
         {
             if( (*pList)[i].GetId() == nId )
@@ -323,18 +323,18 @@ uno::Any SAL_CALL SvxUnoGluePointAccess::getByIdentifier( sal_Int32 Identifier )
 
         if( Identifier < NON_USER_DEFINED_GLUE_POINTS ) // default glue point?
         {
-            SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( (USHORT)Identifier );
+            SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( (sal_uInt16)Identifier );
             aGluePoint.IsUserDefined = sal_False;
             convert( aTempPoint, aGluePoint );
             return uno::makeAny( aGluePoint );
         }
         else
         {
-            const USHORT nId = (USHORT)( Identifier - NON_USER_DEFINED_GLUE_POINTS ) + 1;
+            const sal_uInt16 nId = (sal_uInt16)( Identifier - NON_USER_DEFINED_GLUE_POINTS ) + 1;
 
             const SdrGluePointList* pList = mpObject->GetGluePointList();		
-            const USHORT nCount = pList ? pList->GetCount() : 0;
-            for( USHORT i = 0; i < nCount; i++ )
+            const sal_uInt16 nCount = pList ? pList->GetCount() : 0;
+            for( sal_uInt16 i = 0; i < nCount; i++ )
             {
                 const SdrGluePoint& rTempPoint = (*pList)[i];
                 if( rTempPoint.GetId() == nId )
@@ -360,9 +360,9 @@ uno::Sequence< sal_Int32 > SAL_CALL SvxUnoGluePointAccess::getIdentifiers() thro
     if( mpObject.is() )
     { 
         const SdrGluePointList* pList = mpObject->GetGluePointList();
-        const USHORT nCount = pList ? pList->GetCount() : 0;
+        const sal_uInt16 nCount = pList ? pList->GetCount() : 0;
 
-        USHORT i;
+        sal_uInt16 i;
 
         uno::Sequence< sal_Int32 > aIdSequence( nCount + NON_USER_DEFINED_GLUE_POINTS );
         sal_Int32 *pIdentifier = aIdSequence.getArray();
@@ -427,7 +427,7 @@ void SAL_CALL SvxUnoGluePointAccess::removeByIndex( sal_Int32 Index )
             Index -= 4;
             if( Index >= 0 && Index < pList->GetCount() )
             {
-                pList->Delete( (USHORT)Index );
+                pList->Delete( (sal_uInt16)Index );
                 
                 // only repaint, no objectchange
                 mpObject->ActionChanged();
@@ -456,7 +456,7 @@ void SAL_CALL SvxUnoGluePointAccess::replaceByIndex( sal_Int32 Index, const uno:
         SdrGluePointList* pList = const_cast< SdrGluePointList* >( mpObject->GetGluePointList() );
         if( pList && Index < pList->GetCount() )
         {
-            SdrGluePoint& rGlue = (*pList)[(USHORT)Index];
+            SdrGluePoint& rGlue = (*pList)[(sal_uInt16)Index];
             convert( aUnoGlue, rGlue );
 
             // only repaint, no objectchange
@@ -499,7 +499,7 @@ uno::Any SAL_CALL SvxUnoGluePointAccess::getByIndex( sal_Int32 Index )
 
         if( Index < 4 ) // default glue point?
         {
-            SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( (USHORT)Index );
+            SdrGluePoint aTempPoint = mpObject->GetVertexGluePoint( (sal_uInt16)Index );
             aGluePoint.IsUserDefined = sal_False;
             convert( aTempPoint, aGluePoint );
             uno::Any aAny;
@@ -512,7 +512,7 @@ uno::Any SAL_CALL SvxUnoGluePointAccess::getByIndex( sal_Int32 Index )
             const SdrGluePointList* pList = mpObject->GetGluePointList();
             if( pList && Index < pList->GetCount() )
             {
-                const SdrGluePoint& rTempPoint = (*pList)[(USHORT)Index];
+                const SdrGluePoint& rTempPoint = (*pList)[(sal_uInt16)Index];
                 aGluePoint.IsUserDefined = sal_True;
                 convert( rTempPoint, aGluePoint );
                 uno::Any aAny;
